@@ -32,9 +32,15 @@ INTERNALERROR = 'InternalError'
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 为确保资源不泄露，保证创建的资源ID幂等性。通过ClientToken创建资源，当订单流程已结束且发货失败，或订单流程长时间未更新时，提示当前ClientToken已经超时过期。
+INVALIDPARAMETER_CLIENTTOKENLIMITEXCEEDED = 'InvalidParameter.ClientTokenLimitExceeded'
+
 # 参数格式错误。
 INVALIDPARAMETER_FORMATERROR = 'InvalidParameter.FormatError'
 
+# 查询参数错误。
+INVALIDPARAMETER_INVALIDFILTER = 'InvalidParameter.InvalidFilter'
+
 # 负载均衡实例ID错误。
 INVALIDPARAMETER_LBIDNOTFOUND = 'InvalidParameter.LBIdNotFound'
 
@@ -100,3 +106,6 @@ RESOURCESSOLDOUT = 'ResourcesSoldOut'
 
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
+
+# 操作不支持。
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
